pub trait FromObjectRef: FromValue {
// Required method
fn from_object_ref(value: &mut Object<Value>) -> Self
where Self: Sized;
}Expand description
Implemented for all meta structures which can be created from an object.
Only meta structures which implement FromObjectRef can be flattened.
Required Methods
Sourcefn from_object_ref(value: &mut Object<Value>) -> Selfwhere
Self: Sized,
fn from_object_ref(value: &mut Object<Value>) -> Selfwhere
Self: Sized,
Creates a meta structure from key value pairs.
The implementation is supposed remove used fields from the passed value.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".